@@ -26,7 +26,8 @@ enum reionization_parametrization {
   reio_camb,  /**< reionization parameterized like in CAMB */
   reio_bins_tanh,  /**< binned reionization history with tanh inteprolation between bins */
   reio_half_tanh,  /**< half a tanh, instead of the full tanh */
-  reio_many_tanh   /**< similar to reio_camb but with more than one tanh */
+  reio_many_tanh,  /**< similar to reio_camb but with more than one tanh */
+  reio_inter       /**< linear interpolation between specified points */
 };
 
 /**
@@ -108,6 +109,14 @@ struct thermo
 
   double many_tanh_width; /**< sharpness of tanh() steps */
 
+    /** parameters for reio_inter */
+
+  int reio_inter_num; /**< with how many jumps do we want to describe reionization? */
+
+  double * reio_inter_z; /**< discrete z values */
+
+  double * reio_inter_xe; /**< discrete \f$ X_e(z)\f$ values */
+
   /** parameters for energy injection */
 
   double annihilation; /** parameter describing CDM annihilation (f <sigma*v> / m_cdm, see e.g. 0905.0003) */
@@ -186,7 +195,7 @@ struct thermo
   //@}
 
 
-  /** @name - redshift, conformal time and sound horizon at recombination */
+  /** @name - characteristic quantities like redshift, conformal time and sound horizon at recombination */
 
   //@{
 
@@ -203,13 +212,6 @@ struct thermo
   double rs_d;    /**< comoving sound horizon at baryon drag */
   double tau_cut; /**< at at which the visibility goes below a fixed fraction of the maximum visibility, used for an approximation in perturbation module */
   double angular_rescaling; /**< [ratio ra_rec / (tau0-tau_rec)]: gives CMB rescaling in angular space relative to flat model (=1 for curvature K=0) */
-
-  //@}
-
-  /** @name - redshift, conformal time and sound horizon at recombination */
-
-  //@{
-
   double tau_free_streaming;   /**< minimum value of tau at which sfree-streaming approximation can be switched on */
 
   //@}
@@ -403,7 +405,7 @@ struct reionization {
   int index_helium_fullreio_redshift; /**< helium full reionization redshift */
   int index_helium_fullreio_width;    /**< a width defining the duration of helium full reionization in the reio_camb scheme */
 
-  /* parameters used by reio_bins_tanh and reio_many_tanh */
+  /* parameters used by reio_bins_tanh, reio_many_tanh, reio_inter */
 
   int reio_num_z; /**< number of reionization jumps */
   int index_reio_first_z; /**< redshift at which we start to impose reionization function */
