@@ -24,8 +24,8 @@
 
 /**
  * SECTION:nc_halo_bias_func
- * @title: Mean Halo Bias Function
- * @short_description: FIXME
+ * @title: NcHaloBiasFunc
+ * @short_description: Mean halo bias function.
  *
  * FIXME
  */
@@ -49,7 +49,7 @@ G_DEFINE_TYPE (NcHaloBiasFunc, nc_halo_bias_func, G_TYPE_OBJECT);
 
 /**
  * nc_halo_bias_func_new:
- * @mfp: a #NcMassFunction.
+ * @mfp: a #NcHaloMassFunction.
  * @biasf: (allow-none): a #NcHaloBiasType.
  *
  * This function allocates memory for a new #NcHaloBiasFunc object and sets its properties to the values from
@@ -58,7 +58,7 @@ G_DEFINE_TYPE (NcHaloBiasFunc, nc_halo_bias_func, G_TYPE_OBJECT);
  * Returns: A new #NcHaloBiasFunc.
  */
 NcHaloBiasFunc *
-nc_halo_bias_func_new (NcMassFunction *mfp, NcHaloBiasType *biasf)
+nc_halo_bias_func_new (NcHaloMassFunction *mfp, NcHaloBiasType *biasf)
 {
   NcHaloBiasFunc *mbiasf = g_object_new (NC_TYPE_HALO_BIAS_FUNC,
                                      "mass-function", mfp,
@@ -121,7 +121,7 @@ _nc_halo_bias_func_dispose (GObject *object)
 {
   NcHaloBiasFunc *mbiasf = NC_HALO_BIAS_FUNC (object);
   
-  nc_mass_function_clear (&mbiasf->mfp);
+  nc_halo_mass_function_clear (&mbiasf->mfp);
   nc_halo_bias_type_clear (&mbiasf->biasf);
 
   /* Chain up : end */
@@ -148,7 +148,7 @@ _nc_halo_bias_func_set_property (GObject *object, guint prop_id, const GValue *v
 	  mbiasf->mfp = g_value_dup_object (value);
 	  break;
 	case PROP_BIAS_TYPE:
-	  mbiasf->biasf = g_value_get_boxed (value);
+	  mbiasf->biasf = g_value_dup_object (value);
 	  break;
 	default:
 	  G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -168,7 +168,7 @@ _nc_halo_bias_func_get_property (GObject *object, guint prop_id, GValue *value,
 	  g_value_set_object (value, mbiasf->mfp);
 	  break;
 	case PROP_BIAS_TYPE:
-	  g_value_set_boxed (value, mbiasf->biasf);
+	  g_value_set_object (value, mbiasf->biasf);
 	  break;
 	default:
 	  G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -197,7 +197,7 @@ nc_halo_bias_func_class_init (NcHaloBiasFuncClass *klass)
                                    g_param_spec_object ("mass-function",
                                                         NULL,
                                                         "Mass Function.",
-                                                        NC_TYPE_MASS_FUNCTION,
+                                                        NC_TYPE_HALO_MASS_FUNCTION,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   /*
    * NcHaloBiasFunc:bias-type:
@@ -217,7 +217,7 @@ nc_halo_bias_func_class_init (NcHaloBiasFuncClass *klass)
 /**
  * nc_halo_bias_func_integrand:
  * @mbiasf: a #NcHaloBiasFunc.
- * @model: a #NcHICosmo.
+ * @cosmo: a #NcHICosmo.
  * @lnM: logarithm base e of the mass.
  * @z: redshift.
  *
@@ -230,18 +230,13 @@ nc_halo_bias_func_class_init (NcHaloBiasFuncClass *klass)
  * Returns: a double which corresponds to the mean bias integrand for lnM and at redshift z.
  */
 gdouble
-nc_halo_bias_func_integrand (NcHaloBiasFunc *mbiasf, NcHICosmo *model, gdouble lnM, gdouble z)
+nc_halo_bias_func_integrand (NcHaloBiasFunc *mbiasf, NcHICosmo *cosmo, gdouble lnM, gdouble z)
 {
-  gdouble lnR = nc_matter_var_lnM_to_lnR (mbiasf->mfp->vp, model, lnM);
-  gdouble R = exp (lnR);
-  gdouble M_rho = nc_window_volume (mbiasf->mfp->vp->wp) * gsl_pow_3(R);   /* M/\rho comoving, rho independe de z */
-  gdouble var0 = nc_matter_var_var0 (mbiasf->mfp->vp, model, lnR);
-  gdouble dlnvar0_dlnR = nc_matter_var_dlnvar0_dlnR (mbiasf->mfp->vp, model, lnR);
-  gdouble growth = nc_growth_func_eval (mbiasf->mfp->gf, model, z);
-  gdouble sigma = nc_matter_var_sigma8_sqrtvar0 (mbiasf->mfp->vp, model) * sqrt(var0) * growth;
-  gdouble f = nc_multiplicity_func_eval (mbiasf->mfp->mulf, model, sigma, z);
-  gdouble dn_dlnM = - (1.0/(3.0*M_rho)) * f * 0.5 * dlnvar0_dlnR;  /* dn/dlnM = - (\rho/3M) * f * (R/\sigma)* dsigma_dR */
-  gdouble bias = nc_halo_bias_type_eval (mbiasf->biasf, sigma, z);
+  gdouble sigma, dn_dlnM, bias;
+
+  nc_halo_mass_function_dn_dlnM_sigma (mbiasf->mfp, cosmo, lnM, z, &sigma, &dn_dlnM);
+
+  bias = nc_halo_bias_type_eval (mbiasf->biasf, sigma, z);
 
   return dn_dlnM * bias;
 }
