@@ -40,7 +40,7 @@
 #include "math/ncm_util.h"
 #include "math/ncm_cfg.h"
 #include "math/binsplit.h"
-#include "math/memory_pool.h"
+#include "math/ncm_memory_pool.h"
 
 /**
  * ncm_mpsf_sbessel_recur_new: (skip)
