@@ -261,6 +261,20 @@ ncm_obj_array_peek (NcmObjArray *oa, guint i)
   return g_ptr_array_index ((GPtrArray *)oa, i);
 }
 
+/**
+ * ncm_obj_array_len:
+ * @oa: a #NcmObjArray
+ *
+ * FIXME
+ *
+ * Returns: array length
+ */
+gint
+ncm_obj_array_len (NcmObjArray *oa)
+{
+  return oa->len;
+}
+
 /**
  * ncm_obj_array_save:
  * @oa: a #NcmObjArray
