@@ -31,7 +31,10 @@
 #include <numcosmo/build_cfg.h>
 #include <numcosmo/math/ncm_ode_spline.h>
 #include <numcosmo/math/ncm_rng.h>
+
+#ifndef NUMCOSMO_GIR_SCAN
 #include <gsl/gsl_min.h>
+#endif /* NUMCOSMO_GIR_SCAN */
 
 G_BEGIN_DECLS
 
@@ -64,8 +67,7 @@ struct _NcmStatsDist1d
   gdouble reltol;
   gdouble abstol;
   gdouble max_prob;
-  NcmOdeSpline *inv_P;
-  NcmOdeSpline *inv_Q;
+  NcmOdeSpline *inv_cdf;
   NcmOdeSpline *pdf;
   gsl_min_fminimizer *fmin;
 };
@@ -78,6 +80,9 @@ void ncm_stats_dist1d_clear (NcmStatsDist1d **sd1);
 
 void ncm_stats_dist1d_prepare (NcmStatsDist1d *sd1);
 
+gdouble ncm_stats_dist1d_get_xi (NcmStatsDist1d *sd1);
+gdouble ncm_stats_dist1d_get_xf (NcmStatsDist1d *sd1);
+
 gdouble ncm_stats_dist1d_eval_p (NcmStatsDist1d *sd1, gdouble x);
 gdouble ncm_stats_dist1d_eval_m2lnp (NcmStatsDist1d *sd1, gdouble x);
 gdouble ncm_stats_dist1d_eval_pdf (NcmStatsDist1d *sd1, gdouble x);
