@@ -5,6 +5,7 @@
  *  Copyright  2008  Sandro Dias Pinto Vitenti
  *  <sandro@isoftware.com.br>
  ****************************************************************************/
+
 /*
  * numcosmo
  * Copyright (C) Sandro Dias Pinto Vitenti 2012 <sandro@lapsandro>
@@ -56,18 +57,18 @@ struct _NcDistanceClass
 
 /**
  * NcDistanceComovingMethod:
- * @NC_DISTANCE_COMOVING_METHOD_INT_E: FIXME
- * @NC_DISTANCE_COMOVING_METHOD_FROM_MODEL: FIXME
+ * @NC_DISTANCE_COMOVING_METHOD_INT_E: performs a numerical evaluation.
+ * @NC_DISTANCE_COMOVING_METHOD_FROM_MODEL: uses the method defined by the implementation of #NcHICosmo.
+ *
+ * Enumeration to define which method to be applied in order to compute the cosmological distances.
  *
- * FIXME
- * 
  */
 typedef enum _NcDistanceComovingMethod
 {
   NC_DISTANCE_COMOVING_METHOD_INT_E = 0,
   NC_DISTANCE_COMOVING_METHOD_FROM_MODEL,
   /* < private > */
-  NC_DISTANCE_COMOVING_METHOD_LEN,   /*< skip >*/  
+  NC_DISTANCE_COMOVING_METHOD_LEN, /*< skip >*/
 } NcDistanceComovingMethod;
 
 struct _NcDistance
@@ -76,7 +77,7 @@ struct _NcDistance
   GObject parent_instance;
   NcmOdeSpline *comoving_distance_spline;
   NcmFunctionCache *comoving_distance_cache;
-	NcmFunctionCache *comoving_infinity;
+  NcmFunctionCache *comoving_infinity;
   NcmFunctionCache *time_cache;
   NcmFunctionCache *lookback_time_cache;
   NcmFunctionCache *conformal_time_cache;
@@ -129,7 +130,6 @@ gdouble nc_distance_shift_parameter_lss (NcDistance *dist, NcHICosmo *cosmo);
 gdouble nc_distance_comoving_lss (NcDistance *dist, NcHICosmo *cosmo);
 gdouble nc_distance_acoustic_scale (NcDistance *dist, NcHICosmo *cosmo);
 gdouble nc_distance_theta100CMB (NcDistance *dist, NcHICosmo *cosmo);
-gdouble nc_distance_Omega_k0 (NcDistance *dist, NcHICosmo *cosmo);
 gdouble nc_distance_angular_diameter_curvature_scale (NcDistance *dist, NcHICosmo *cosmo);
 gdouble nc_distance_r_zd (NcDistance *dist, NcHICosmo *cosmo);
 gdouble nc_distance_r_zd_Mpc (NcDistance *dist, NcHICosmo *cosmo);
@@ -138,24 +138,27 @@ gdouble nc_distance_r_zd_Mpc (NcDistance *dist, NcHICosmo *cosmo);
  * Redshift dependent 'distances'
  ****************************************************************************/
 
-gdouble nc_distance_comoving (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_transverse (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_dtransverse_dz (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_luminosity (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_angular_diameter (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_dmodulus (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_luminosity_hef (NcDistance *dist, NcHICosmo *cosmo, gdouble z_he, gdouble z_cmb);
-gdouble nc_distance_dmodulus_hef (NcDistance *dist, NcHICosmo *cosmo, gdouble z_he, gdouble z_cmb);
-gdouble nc_distance_shift_parameter (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_dilation_scale (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_bao_A_scale (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_sound_horizon (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_dsound_horizon_dz (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_bao_r_Dv (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_DH_r (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_DA_r (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_comoving_z_to_infinity (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_transverse_z_to_infinity (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
+gdouble nc_distance_comoving (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_transverse (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_dtransverse_dz (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_luminosity (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_angular_diameter (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_dmodulus (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_luminosity_hef (NcDistance *dist, NcHICosmo *cosmo, const gdouble z_he, const gdouble z_cmb);
+gdouble nc_distance_dmodulus_hef (NcDistance *dist, NcHICosmo *cosmo, const gdouble z_he, const gdouble z_cmb);
+gdouble nc_distance_shift_parameter (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_dilation_scale (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_bao_A_scale (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_sound_horizon (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_dsound_horizon_dz (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_bao_r_Dv (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_DH_r (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_DA_r (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_comoving_z_to_infinity (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_transverse_z_to_infinity (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+
+gdouble nc_distance_transverse_z1_z2 (NcDistance *dist, NcHICosmo *cosmo, const gdouble z1, const gdouble z2);
+gdouble nc_distance_angular_diameter_z1_z2 (NcDistance *dist, NcHICosmo *cosmo, const gdouble z1, const gdouble z2);
 
 /***************************************************************************
  *            cosmic_time.h
@@ -165,10 +168,10 @@ gdouble nc_distance_transverse_z_to_infinity (NcDistance *dist, NcHICosmo *cosmo
  *  <sandro@isoftware.com.br>
  ****************************************************************************/
 
-gdouble nc_distance_cosmic_time (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_lookback_time (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_conformal_time (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
-gdouble nc_distance_conformal_lookback_time (NcDistance *dist, NcHICosmo *cosmo, gdouble z);
+gdouble nc_distance_cosmic_time (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_lookback_time (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_conformal_time (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
+gdouble nc_distance_conformal_lookback_time (NcDistance *dist, NcHICosmo *cosmo, const gdouble z);
 
 G_END_DECLS
 
@@ -193,3 +196,4 @@ G_END_DECLS
 #endif /* __GTK_DOC_IGNORE__ */
 #endif /* NUMCOSMO_HAVE_INLINE */
 #endif /* _NC_DISTANCE_INLINE_H_ */
+
